#!/usr/bin/perl -w

#------------------------------------------------------------------------------
#          Harvard University Atmospheric Chemistry Modeling Group            !
#------------------------------------------------------------------------------
#BOP
#
# !MODULE: mean_oh.pl
#
# !DESCRIPTION: This Perl script computes the mean OH concentration of a 1-yr
#  GEOS-Chem benchmark simulation.  It reads the mean OH values printed to
#  the log file of each successive run stage and computes the average.
#\\
#\\
# !USES:
#
   require 5.003;       
   use strict;
#
# !CALLING SEQUENCE:
#  mean_oh.pl
#
# !REVISION HISTORY: 
#  07 Jun 2011 - R. Yantosca - Initial version
#EOP
#------------------------------------------------------------------------------
#BOC

# Arrays
my @files  = qw( log.13 log.14 log.15 log.16 log.17 log.18 log.19 log.20 log.21 log.22 log.23 log.24 );
my @result = ();

# Scalars
my $file   = "";
my $oh     = 0;

# Loop over all files
foreach $file ( @files ) {

  # Split the line into substrings.  The mean OH value 
  # is in the 4th substring (indexed by $result[3]).
  @result = split( ' ', qx( grep 1e5 $file ) );

  # Sum the 
  $oh    += $result[3];

  # Echo info
  print "Mean OH from $file: $result[3] [1e5 molec/cm3]\n";
}

# Take the average
$oh /= scalar( @files );

# Echo result
print "\nTotal Mean OH: $oh\n [1e5 molec/cm3]";

# Exit normally
exit(0);
#EOC
